var CHARACTER_BLOCK_ID = 'characters';
var CHARACTER_FILE_URI = '/character.xml';
var CHARACTER_IMAGE_PATH = '/img/character/';

/* ------------------------------------------------------------------------------ */

var Character = Class.create();
Character.prototype = {
    name: '',
    level: 0,
    sex: null,
    job: null,
    status: null,
    comment: '',
    image: '',
    equipment: null,
    initialize: function(name, level, sex, job, status, comment, image, equipment) {
        this.name = name;
        this.level = level;
        this.sex = sex;
        this.job = job;
        this.status = status;
        this.comment = comment;
        this.image = image;
        this.equipment = equipment;
    },
    toNode: function() {
        var characterNode = document.createElement('ul');
        characterNode.setAttribute('class', 'character');
        characterNode.setAttribute('className', 'character');
        var imageNode = null;
        if(this.image != '') {
            imageNode = document.createElement('li');
            var innerImageNode = document.createElement('img');
            innerImageNode.setAttribute('alt', this.name);
            innerImageNode.setAttribute('title', this.name);
            innerImageNode.setAttribute('src', CHARACTER_IMAGE_PATH + this.image);
            imageNode.appendChild(innerImageNode);
        }
        var nameNode = document.createElement('li');
        nameNode.appendChild(document.createTextNode(this.name));
        var levelNode = document.createElement('li');
        levelNode.appendChild(document.createTextNode('Level: ' + this.level.toString()));
        var sexAndJobNode = document.createElement('li');
        sexAndJobNode.appendChild(document.createTextNode('Class:' + this.sex.toString() + this.job.toString()));
        var statusNode = document.createElement('li');
        statusNode.appendChild(document.createTextNode('Status: ' + this.status.toString()));
        var commentNode = document.createElement('li');
        commentNode.appendChild(document.createTextNode(this.comment));
        if(imageNode != null)
            characterNode.appendChild(imageNode);
        characterNode.appendChild(nameNode);
        characterNode.appendChild(levelNode);
        characterNode.appendChild(sexAndJobNode);
        characterNode.appendChild(statusNode);
        characterNode.appendChild(commentNode);
        if(this.equipment != null) {
            var equipmentNode = document.createElement('div');
            equipmentNode.setAttribute('class', 'equipment');
            equipmentNode.setAttribute('className', 'equipment');
            var listNode = document.createElement('ul');
            equipmentNode.appendChild(listNode);
            $A(this.equipment.getElementsByTagName('category')).each(function(category) {
                var categoryNode = document.createElement('li');
                var categoryNodeBlock = document.createElement('div');
                var categoryNameNode = document.createElement('span');
                categoryNameNode.setAttribute('class', 'categoryName');
                categoryNameNode.setAttribute('className', 'categoryName');
                categoryNameNode.appendChild(document.createTextNode(category.getAttribute('name')));
                categoryNodeBlock.appendChild(categoryNameNode);
                var itemListNode = document.createElement('ul');
                itemListNode.setAttribute('class', 'equipmentList');
                itemListNode.setAttribute('className', 'equipmentList');
                categoryNodeBlock.appendChild(itemListNode);
                categoryNode.appendChild(categoryNodeBlock);
                equipmentNode.appendChild(categoryNode);
                $A(category.getElementsByTagName('item')).each(function(item) {
                    var listItemNode = document.createElement('li');
                    var enchantElements = item.getElementsByTagName('enchant');
                    var enchant = null;
                    if(0 < enchantElements.length)
                        enchant = enchantElements[0].firstChild.nodeValue;
                    var nameElement = item.getElementsByTagName('name')[0];
                    var itemText = '';
                    if(enchant != null) {
                        itemText = itemText.concat(enchant + ' ');
                        itemText = itemText.concat(nameElement.firstChild.nodeValue);
                    } else {
                        itemText = nameElement.firstChild.nodeValue;
                    }
                    listItemNode.appendChild(document.createTextNode(itemText));
                    itemListNode.appendChild(listItemNode);
                });
            });
            characterNode.appendChild(equipmentNode);
        }
        return characterNode;
    }
}

var Status = Class.create();
Status.prototype = {
    strength: '0',
    dexterity: '0',
    constitution: '0',
    intelligence: '0',
    wisdom: '0',
    charisma: '0',
    initialize: function(strength, dexterity, constitution, intelligence, wisdom, charisma) {
        this.strength = strength;
        this.dexterity = dexterity;
        this.constitution = constitution;
        this.intelligence = intelligence;
        this.wisdom = wisdom;
        this.charisma = charisma;
    },
    toString: function() {
        var str =
            'STR' + this.strength + ' ' +
            'DEX' + this.dexterity + ' ' +
            'CON' + this.constitution + ' ' +
            'INT' + this.intelligence + ' ' +
            'WIS' + this.wisdom + ' ' +
            'CHA' + this.charisma;
        return str;
    }
}

var Sex = Class.create();
Sex.prototype = {
    sexText: '',
    initialize: function(sexText) { this.sexText = sexText; },
    toString: function() {
        switch(this.sexText) {
            case 'male':
                return '♂';
            case 'female':
                return '♀';
            default:
                return this.sexText;
        }
    }
}

var Job = Class.create();
Job.prototype = {
    jobText: '',
    initialize: function(jobText) { this.jobText = jobText; },
    toString: function() {
        switch (this.jobText) {
            case 'prince':
            case 'princess':
                return 'プリ';
            case 'knight':
                return 'ナイト';
            case 'elf':
                return 'エルフ';
            case 'wizard':
                return 'ウィザード';
            case 'darkelf':
                return 'ダークエルフ';
            case 'dragonkight':
                return 'ドラゴンナイト';
            case 'illusionist':
                return 'イリュージョニスト';
            default:
                return this.jobText;
        }
    }
}

/* ------------------------------------------------------------------------------ */

// onload
addEvent(window, 'load', showCharacter);

/* ------------------------------------------------------------------------------ */

function showCharacter() {
    createLoading();
    showLoading();
    new Ajax.Request(
        CHARACTER_FILE_URI,
        {
            method: 'get',
            onSuccess: characterSuccess,
            onComplete: characterComplete,
            onFailure: characterFailure
        }
    );
}

function characterSuccess(file) {
    hideLoading();
    addCharacters(file.responseXML.documentElement);
}
function characterComplete() { }
function characterFailure() { }

/* ------------------------------------------------------------------------------ */

function addCharacters(root) {
    var characterBlock = $(CHARACTER_BLOCK_ID);
    var characters = $A(root.getElementsByTagName('character'));
    var characterList = new Array();
    characters.each(function(character){
        var nameNode = character.getElementsByTagName('name')[0];
        var levelNode = character.getElementsByTagName('level')[0];
        var sexNode = character.getElementsByTagName('sex')[0];
        var jobNode = character.getElementsByTagName('job')[0];
        
        var statusNode = character.getElementsByTagName('status')[0];
        var strength = statusNode.getElementsByTagName('strength')[0].firstChild.nodeValue;
        var dexterity = statusNode.getElementsByTagName('dexterity')[0].firstChild.nodeValue;
        var constitution = statusNode.getElementsByTagName('constitution')[0].firstChild.nodeValue;
        var intelligence = statusNode.getElementsByTagName('intelligence')[0].firstChild.nodeValue;
        var wisdom = statusNode.getElementsByTagName('wisdom')[0].firstChild.nodeValue;
        var charisma = statusNode.getElementsByTagName('charisma')[0].firstChild.nodeValue;
        
        var commentNode = character.getElementsByTagName('comment')[0];
        var imageNodes = character.getElementsByTagName('image');
        var image = '';
        if(0 < imageNodes.length)
            image = imageNodes[0].firstChild.nodeValue;
        var equipmentNodes = character.getElementsByTagName('equipment');
        var equipment = null;
        if(0 < equipmentNodes.length)
            equipment = equipmentNodes[0];
        characterList.push(
            new Character(
                nameNode.firstChild.nodeValue,
                levelNode.firstChild.nodeValue,
                new Sex(sexNode.firstChild.nodeValue),
                new Job(jobNode.firstChild.nodeValue),
                new Status(strength, dexterity, constitution, intelligence, wisdom, charisma),
                commentNode.firstChild.nodeValue,
                image,
                equipment)
        );
    });
    characterList.each(function(character) {
        characterBlock.appendChild(character.toNode());
    });
    removeLoading();
}